@@ -60,17 +60,15 @@ sub DESTROY {
 
 sub debug {
   my ($self, $format, @message) = @_;
-  my $tracefile = "/tmp/".$Monitoring::GLPlugin::pluginname.".trace";
-  $self->{trace} = -f $tracefile ? 1 : 0;
   if ($self->opts->verbose && $self->opts->verbose > 10) {
     printf("%s: ", scalar localtime);
     printf($format, @message);
     printf "\n";
   }
-  if ($self->{trace}) {
+  if ($Monitoring::GLPlugin::tracefile) {
     my $logfh = IO::File->new();
     $logfh->autoflush(1);
-    if ($logfh->open($tracefile, "a")) {
+    if ($logfh->open($Monitoring::GLPlugin::tracefile, "a")) {
       $logfh->printf("%s: ", scalar localtime);
       $logfh->printf($format, @message);
       $logfh->printf("\n");
@@ -399,7 +397,8 @@ sub nagios_exit {
     # negate again: --negate "UNKNOWN - no peers"=ok
     my $original_code = $code;
     foreach my $from (keys %{$self->opts->negate}) {
-      if ((uc $self->opts->negate->{$from}) =~ /^(OK|WARNING|CRITICAL|UNKNOWN)$/) {
+      if ((uc $from) !~ /^(OK|WARNING|CRITICAL|UNKNOWN)$/ &&
+          (uc $self->opts->negate->{$from}) =~ /^(OK|WARNING|CRITICAL|UNKNOWN)$/) {
         if ($output =~ /$from/) {
           $code = $ERRORS{uc $self->opts->negate->{$from}};
           $output =~ s/^.*? -/$STATUS_TEXT{$code} -/;
@@ -418,6 +417,7 @@ sub nagios_exit {
         $output;
   }
   if (! exists $self->{suppress_messages}) {
+    $output =~ s/[^[:ascii:]]//g;
     print $output;
   }
   exit $code;
@@ -597,6 +597,15 @@ sub check_thresholds {
   return $level;
 }
 
+sub strequal {
+  my($self, $str1, $str2) = @_;
+  return 1 if ! defined $str1 && ! defined $str2;
+  return 0 if ! defined $str1 && defined $str2;
+  return 0 if defined $str1 && ! defined $str2;
+  return 1 if $str1 eq $str2;
+  return 0;
+}
+
 1;
 
 __END__
