@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('BLUECOAT-AV-MIB', (qw(
       avSlowICAPConnections)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf '%d slow ICAP connections',
       $self->{avSlowICAPConnections});
   $self->set_thresholds(warning => 100, critical => 100);
