@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('BLUECOAT-AV-MIB', (qw(
       avLicenseDaysRemaining avVendorName)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf 'license %s expires in %d days',
       $self->{avVendorName},
       $self->{avLicenseDaysRemaining});
