@@ -4,7 +4,7 @@ use strict;
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   if ($self->mode =~ /device::ha::role/) {
     $self->get_snmp_objects('WLSX-SYSTEMEXT-MIB', (qw(wlsxSysExtSwitchRole)));
     if (! $self->opts->role()) {
@@ -14,7 +14,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking ha');
   $self->add_info(sprintf 'ha role is %s', $self->{wlsxSysExtSwitchRole});
   if ($self->{wlsxSysExtSwitchRole} ne $self->opts->role()) {
