@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_tables('WLSX-SYSTEMEXT-MIB', [
       ['storage', 'wlsxSysExtStorageTable', 'Classes::Alcatel::OmniAccess::Component::StorageSubsystem::Storageory'],
   ]);
@@ -15,12 +15,12 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
 sub finish {
-  my $self = shift;
+  my ($self) = @_;
   $self->{usage} = 100 * $self->{sysExtStorageUsed} / $self->{sysExtStorageSize};
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   my $label = sprintf 'storage_%s_usage', $self->{sysExtStorageName};
   $label =~ s/\s+/_/g;
   $self->add_info(sprintf 'storage %s usage is %.2f%%',
