@@ -4,8 +4,8 @@ use strict;
 
 
 sub init {
-  my $self = shift;
-  if ($self->{productname} =~ /Blue.*Coat.*(SG\d+|SGOS)/i) {
+  my ($self) = @_;
+  if ($self->{productname} =~ /Blue.*Coat.*(SG\d+|SGOS|ASG)/i) {
     # product ProxySG  Blue Coat SG600
     # iso.3.6.1.4.1.3417.2.11.1.3.0 = STRING: "Version: SGOS 5.5.8.1, Release id: 78642 Proxy Edition"
     bless $self, 'Classes::SGOS';
