@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('CHECKPOINT-MIB', (qw(
       fwModuleState fwPolicyName fwNumConn)));
   if ($self->mode =~ /device::fw::policy::installed/) {
@@ -12,7 +12,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking fw module');
   if ($self->{fwModuleState} ne 'Installed') {
     $self->add_critical(sprintf 'fw module is %s', $self->{fwPolicyName});
