@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_tables('CISCO-FIREWALL-MIB', [
       ['connectionstates', 'cfwConnectionStatTable', 'Classes::Cisco::IOS::Component::ConnectionSubsystem::ConnectionState'],
   ]);
@@ -14,14 +14,14 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   if ($self->{cfwConnectionStatDescription} !~ /number of connections currently in use/i) {
     $self->add_blacklist(sprintf 'c:%s', $self->{cfwConnectionStatDescription});
     $self->add_info(sprintf '%d connections currently in use',
-        $self->{cfwConnectionStatValue}||$self->{cfwConnectionStatCount}, $self->{usage});
+        ($self->{cfwConnectionStatValue}||$self->{cfwConnectionStatCount}));
   } else {
     $self->add_info(sprintf '%d connections currently in use',
-        $self->{cfwConnectionStatValue}, $self->{usage});
+        $self->{cfwConnectionStatValue});
     $self->set_thresholds(warning => 500000, critical => 750000);
     $self->add_message($self->check_thresholds($self->{cfwConnectionStatValue}));
     $self->add_perfdata(
