@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   # schaut eher schlecht aus, das zeugs ist nicht main memory wie ueblich
   $self->get_snmp_objects('CISCOSB-SYSMNG-MIB', (qw(
       rlSysmngResourcePerUnitEntry
@@ -17,6 +17,6 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
 }
 
