@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('AIRESPACE-SWITCHING-MIB', (qw(
       agentTotalMemory agentFreeMemory)));
   $self->{memory_usage} = $self->{agentFreeMemory} ? 
@@ -11,7 +11,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf 'memory usage is %.2f%%',
       $self->{memory_usage});
   $self->set_thresholds(warning => 80, critical => 90);
