@@ -2,16 +2,8 @@ package Classes::F5::F5BIGIP::Component::EnvironmentalSubsystem;
 our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
-sub new {
-  my $class = shift;
-  my $self = {};
-  bless $self, $class;
-  $self->init();
-  return $self;
-}
-
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->{cpu_subsystem} =
       Classes::F5::F5BIGIP::Component::CpuSubsystem->new();
   $self->{fan_subsystem} =
@@ -25,7 +17,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->{cpu_subsystem}->check();
   $self->{fan_subsystem}->check();
   $self->{temperature_subsystem}->check();
@@ -35,7 +27,7 @@ sub check {
 }
 
 sub dump {
-  my $self = shift;
+  my ($self) = @_;
   $self->{cpu_subsystem}->dump();
   $self->{fan_subsystem}->dump();
   $self->{temperature_subsystem}->dump();
