@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem} =
       Classes::FabOS::Component::SensorSubsystem->new();
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem}->check();
   if (! $self->check_messages()) {
     $self->add_ok("environmental hardware working fine");
@@ -17,7 +17,7 @@ sub check {
 }
 
 sub dump {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem}->dump();
 }
 
