@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->bulk_is_baeh();
   $self->get_snmp_tables('SW-MIB', [
       ['sensors', 'swSensorTable', 'Classes::FabOS::Component::SensorSubsystem::Sensor'],
@@ -16,7 +16,7 @@ use strict;
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf '%s sensor %s (%s) is %s',
       $self->{swSensorType},
       $self->{swSensorIndex},
@@ -41,27 +41,3 @@ sub check {
   }
 }
 
-
-package Classes::FabOS::Component::SensorSubsystem::SensorThreshold;
-our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
-use strict;
-
-sub new {
-  my $class = shift;
-  my %params = @_;
-  my $self = {
-    blacklisted => 0,
-    info => undef,
-    extendedinfo => undef,
-  };
-  foreach my $param (qw(entSensorThresholdRelation entSensorThresholdValue
-      entSensorThresholdSeverity entSensorThresholdNotificationEnable
-      entSensorThresholdEvaluation indices)) {
-    $self->{$param} = $params{$param};
-  }
-  $self->{entPhysicalIndex} = $params{indices}[0];
-  $self->{entSensorThresholdIndex} = $params{indices}[1];
-  bless $self, $class;
-  return $self;
-}
-
