@@ -3,15 +3,14 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
-  my %params = @_;
+  my ($self, %params) = @_;
   my $type = 0;
   $self->get_snmp_objects('FORTINET-FORTIGATE-MIB', (qw(
       fgSysCpuUsage)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   my $errorfound = 0;
   $self->add_info('checking cpus');
   $self->add_info(sprintf 'cpu usage is %.2f%%', $self->{fgSysCpuUsage});
