@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem} =
       Classes::Fortigate::Component::SensorSubsystem->new();
   $self->{disk_subsystem} =
@@ -11,7 +11,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem}->check();
   $self->{disk_subsystem}->check();
   if (! $self->check_messages()) {
@@ -20,7 +20,7 @@ sub check {
 }
 
 sub dump {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem}->dump();
   $self->{disk_subsystem}->dump();
 }
