@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_tables('FOUNDRY-SN-AGENT-MIB', [
       ['fans', 'snChasFanTable', 'Classes::Foundry::Component::FanSubsystem::Fan'],
   ]);
@@ -15,12 +15,12 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
 sub finish {
-  my $self = shift;
+  my ($self) = @_;
   $self->{snChasFanDescription} ||= 'fan '.$self->{snChasFanIndex};
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf '%s status is %s',
       $self->{snChasFanDescription},
       $self->{snChasFanOperStatus});
