@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('FOUNDRY-SN-AGENT-MIB', (qw(
       snAgGblDynMemUtil snAgGblDynMemTotal snAgGblDynMemFree)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking memory');
   if (defined $self->{snAgGblDynMemUtil}) {
     $self->add_info(sprintf 'memory usage is %.2f%%',
