@@ -3,23 +3,18 @@ our @ISA = qw(Classes::HH3C::Component::EntitySubsystem);
 use strict;
 
 sub init {
-  my $self = shift;
-
-  $self->get_entities('Classes::HH3C::Component::EnvironmentalSubsystem::EntityState');
-
-  my $i = 0;
-  foreach my $h ($self->get_sub_table('HH3C-ENTITY-EXT-MIB', [ 'hh3cEntityExtErrorStatus' ])) {
-    foreach (keys %$h) {
-      next if $_ =~ /indices/;
-      @{$self->{entities}}[$i]->{$_} = $h->{$_};
-    }
-    $i++;
-  }
+  my ($self) = @_;
+  $self->get_snmp_tables("ENTITY-MIB", [
+    ["entities", "entPhysicalTable", "Classes::HH3C::Component::EnvironmentalSubsystem::Entity", undef, ["entPhysicalDescr", "entPhysicalName", "entPhysicalClass"]]
+  ]);
+  $self->get_snmp_tables("HH3C-ENTITY-EXT-MIB", [
+    ["entitystates", "hh3cEntityExtStateTable", "Classes::HH3C::Component::EnvironmentalSubsystem::EntityState", undef, ["hh3cEntityExtErrorStatus"]]
+  ]);
+  $self->merge_tables("entities", "entitystates");
 }
 
 sub check {
-  my $self = shift;
-
+  my ($self) = @_;
   $self->add_info('checking entities');
   if (scalar (@{$self->{entities}}) == 0) {
     $self->add_unknown('no entities found');
@@ -28,7 +23,7 @@ sub check {
       $_->check();
     }
     if (! $self->check_messages()) {
-      $self->add_ok("environmental hardware working fine");
+      $self->reduce_messages_short("environmental hardware working fine");
     }
   }
 }
@@ -37,14 +32,21 @@ package Classes::HH3C::Component::EnvironmentalSubsystem::EntityState;
 our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
+package Classes::HH3C::Component::EnvironmentalSubsystem::Entity;
+our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
+use strict;
+
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf '%s (%s) is %s',
-      $self->{entPhysicalDescr},
+      $self->{entPhysicalName} || $self->{entPhysicalDescr},
       $self->{entPhysicalClass},
       $self->{hh3cEntityExtErrorStatus});
 
-  if ($self->{hh3cEntityExtErrorStatus} eq "normal") {
+  if ($self->{hh3cEntityExtErrorStatus} eq "notSupported") {
+    # no health check implemented for this entity
+    $self->add_ok();
+  } elsif ($self->{hh3cEntityExtErrorStatus} eq "normal") {
     $self->add_ok();
   } elsif (
     $self->{hh3cEntityExtErrorStatus} eq "entityAbsent" or
@@ -55,3 +57,4 @@ sub check {
     $self->add_critical();
   }
 }
+
