@@ -3,22 +3,19 @@ our @ISA = qw(Classes::HH3C::Component::EntitySubsystem);
 use strict;
 
 sub init {
-  my $self = shift;
-
-  $self->get_entities('Classes::HH3C::Component::MemSubsystem::EntityState',
-    sub { my $o = shift; $o->{entPhysicalClass} eq 'module' and $o->{entPhysicalName} =~ /board/i; } );
-
-  foreach ($self->get_sub_table('HH3C-ENTITY-EXT-MIB', [ 'hh3cEntityExtMemAvgUsage' ])) {
-    push @{$self->{entityext}}, $_;
-  }
-
-  $self->join_table($self->{entities}, $self->{entityext});
+  my ($self) = @_;
+  $self->get_snmp_tables("ENTITY-MIB", [
+    ["entities", "entPhysicalTable", "Classes::HH3C::Component::MemSubsystem::Entity", sub { my ($o) = @_; $o->{entPhysicalClass} eq 'module' and $o->{entPhysicalName} =~ /board/i; }, ["entPhysicalDescr", "entPhysicalName", "entPhysicalClass"]]
+  ]);
+  $self->get_snmp_tables("HH3C-ENTITY-EXT-MIB", [
+    ["entitystates", "hh3cEntityExtStateTable", "Classes::HH3C::Component::MemSubsystem::EntityState", undef, ["hh3cEntityExtMemAvgUsage"]]
+  ]);
+  $self->merge_tables("entities", "entitystates");
 }
 
 sub check {
-  my $self = shift;
-
-  $self->add_info('checking board');
+  my ($self) = @_;
+  $self->add_info('checking memory');
   if (scalar (@{$self->{entities}}) == 0) {
     $self->add_unknown('no board found');
   } else {
@@ -33,10 +30,12 @@ package Classes::HH3C::Component::MemSubsystem::EntityState;
 our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
-sub check {
-  my $self = shift;
-  my $id = shift;
+package Classes::HH3C::Component::MemSubsystem::Entity;
+our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
+use strict;
 
+sub check {
+  my ($self, $id) = @_;
   $self->add_info(sprintf 'Memory %s usage is %s%%',
       $id,
       $self->{hh3cEntityExtMemAvgUsage});
