@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('STATISTICS-MIB', (qw(
       hpSwitchCpuStat)));
   if (! defined $self->{hpSwitchCpuStat}) {
@@ -13,7 +13,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking cpus');
   $self->add_info(sprintf 'cpu usage is %.2f%%', $self->{hpSwitchCpuStat});
   $self->set_thresholds(warning => 80, critical => 90); # maybe lower, because the switching is done in hardware
