@@ -3,8 +3,8 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
-  if ($self->implements_mib('HP-ICF-CHASSIS-MIB')) {
+  my ($self) = @_;
+  if ($self->implements_mib('HP-ICF-CHASSIS')) {
     $self->analyze_and_check_sensor_subsystem('Classes::HP::Procurve::Component::SensorSubsystem');
   } else {
     $self->analyze_and_check_environmental_subsystem("Classes::ENTITYSENSORMIB::Component::EnvironmentalSubsystem");
