@@ -11,6 +11,8 @@ sub init {
   my @ethertable_columns = qw();
   my @ethertablehc_columns = qw();
   my @rmontable_columns = qw();
+  my @ipaddress_columns = qw();
+  $self->implements_mib('INET-ADDRESS-MIB');
   if ($self->mode =~ /device::interfaces::list/) {
   } elsif ($self->mode =~ /device::interfaces::complete/) {
     push(@iftable_columns, qw(
@@ -25,6 +27,9 @@ sub init {
         ifHCInBroadcastPkts ifHCOutBroadcastPkts
         ifHCInUcastPkts ifHCOutUcastPkts
     ));
+    # kostenpflichtiges feature # push(@ethertable_columns, qw(
+    #    dot3StatsDuplexStatus
+    #));
   } elsif ($self->mode =~ /device::interfaces::usage/) {
     push(@iftable_columns, qw(
         ifInOctets ifOutOctets ifSpeed ifOperStatus
@@ -85,20 +90,20 @@ sub init {
       @ethertable_columns = grep {
         my $ec = $_;
         grep {
-	  $ec eq $_;
-	} @reports;
+          $ec eq $_;
+        } @reports;
       } @ethertable_columns;
       @ethertablehc_columns = grep {
         my $ec = $_;
         grep {
-	  $ec eq $_;
-	} @reports;
+          $ec eq $_;
+        } @reports;
       } @ethertablehc_columns;
       @rmontable_columns = grep {
         my $ec = $_;
         grep {
-	  $ec eq $_;
-	} @reports;
+          $ec eq $_;
+        } @reports;
       } @rmontable_columns;
     }
     if (grep /dot3HCStatsFCSErrors/, @ethertablehc_columns) {
@@ -113,6 +118,19 @@ sub init {
           etherStatsDataSource
       ));
     }
+  } elsif ($self->mode =~ /device::interfaces::duplex/) {
+    push(@iftable_columns, qw(
+        ifType ifSpeed ifOperStatus ifAdminStatus ifHighSpeed
+    ));
+    push(@ethertable_columns, qw(
+        dot3StatsDuplexStatus
+    ));
+  } elsif ($self->mode =~ /device::interfaces::uptime/) {
+    push(@iftable_columns, qw(
+        ifLastChange
+    ));
+  } else {
+    @iftable_columns = ();
   }
   if ($self->mode =~ /device::interfaces::list/) {
     $self->update_interface_cache(1);
@@ -121,15 +139,17 @@ sub init {
       my $ifDescr = $self->{interface_cache}->{$ifIndex}->{ifDescr};
       my $ifName = $self->{interface_cache}->{$ifIndex}->{ifName} || '________';
       my $ifAlias = $self->{interface_cache}->{$ifIndex}->{ifAlias} || '________';
-      push(@{$self->{interfaces}},
-          Classes::IFMIB::Component::InterfaceSubsystem::Interface->new(
-              ifIndex => $ifIndex,
-              ifDescr => $ifDescr,
-              ifName => $ifName,
-              ifAlias => $ifAlias,
-              indices => [$ifIndex],
-              flat_indices => $ifIndex,
-          ));
+      my $interface_class = ref($self)."::Interface";
+      my $interface = $interface_class->new(
+          ifIndex => $ifIndex,
+          ifDescr => $ifDescr,
+          ifName => $ifName,
+          ifAlias => $ifAlias,
+          indices => [$ifIndex],
+          flat_indices => $ifIndex,
+      );
+      $self->enrich_interface_attributes($interface);
+      push(@{$self->{interfaces}}, $interface);
     }
     # die sind mit etherStatsDataSource verknuepft
   } elsif ($self->mode =~ /device::interfaces/) {
@@ -138,6 +158,14 @@ sub init {
         $self->opts->name && $self->opts->name eq '_adminup_' ? 1 : 0;
     my $only_oper_up =
         $self->opts->name && $self->opts->name eq '_operup_' ? 1 : 0;
+    # --name '(lan|wan|_adminup_)'
+    # alle mit match auf lan|wan, und davon dann die mit admin up
+    my $plus_admin_up =
+        $self->opts->name && ! $only_admin_up &&
+        $self->opts->name =~ /_adminup_/ ? 1 : 0;
+    my $plus_oper_up =
+        $self->opts->name && ! $only_oper_up &&
+        $self->opts->name =~ /_operup_/ ? 1 : 0;
     if ($only_admin_up || $only_oper_up) {
       $self->override_opt('name', undef);
       $self->override_opt('drecksptkdb', undef);
@@ -150,18 +178,23 @@ sub init {
       @indices = ();
       $self->bulk_is_baeh(10);
     }
-    if (! $self->opts->name || scalar(@indices) > 0) {
+    if ((! $self->opts->name && ! $self->opts->name3) || scalar(@indices) > 0) {
       my @save_indices = @indices; # die werden in get_snmp_table_objects geshiftet
       foreach ($self->get_snmp_table_objects(
           'IFMIB', 'ifTable+ifXTable', \@indices, \@iftable_columns)) {
         next if $only_admin_up && $_->{ifAdminStatus} ne 'up';
         next if $only_oper_up && $_->{ifOperStatus} ne 'up';
+        next if $plus_admin_up && $_->{ifAdminStatus} ne 'up';
+        next if $plus_oper_up && $_->{ifOperStatus} ne 'up';
         $self->make_ifdescr_unique($_);
-        my $interface = Classes::IFMIB::Component::InterfaceSubsystem::Interface->new(%{$_});
+        $self->enrich_interface_attributes($_);
+        my $interface_class = ref($self)."::Interface";
+        my $interface = $interface_class->new(%{$_});
         $interface->{columns} = [@iftable_columns];
         push(@{$self->{interfaces}}, $interface);
       }
-      if ($self->mode =~ /device::interfaces::etherstats/) {
+      # kostenpflichtiges feature # if ($self->mode =~ /device::interfaces::(duplex|etherstats|complete)/) {
+      if ($self->mode =~ /device::interfaces::(duplex|etherstats)/) {
         @indices = @save_indices;
         my @etherindices = ();
         my @etherhcindices = ();
@@ -206,13 +239,13 @@ sub init {
           # es gibt interfaces mit ifSpeed == 4294967295
           # aber nix in dot3HCStatsTable. also dann dot3StatsTable fuer alle
           foreach my $etherstat ($self->get_snmp_table_objects(
-              'ETHERLIKE-MIB', 'dot3StatsTable', \@etherindices, \@ethertable_columns)) {
+              'EtherLike-MIB', 'dot3StatsTable', \@etherindices, \@ethertable_columns)) {
             foreach my $interface (@{$self->{interfaces}}) {
               if ($interface->{ifIndex} == $etherstat->{flat_indices}) {
                 foreach my $key (grep /^dot3/, keys %{$etherstat}) {
                   $interface->{$key} = $etherstat->{$key};
+                  push(@{$interface->{columns}}, $key);
                 }
-                push(@{$interface->{columns}}, @ethertable_columns);
                 last;
               }
             }
@@ -220,13 +253,13 @@ sub init {
         }
         if (@ethertablehc_columns && scalar(@etherhcindices)) {
           foreach my $etherstat ($self->get_snmp_table_objects(
-              'ETHERLIKE-MIB', 'dot3HCStatsTable', \@etherhcindices, \@ethertablehc_columns)) {
+              'EtherLike-MIB', 'dot3HCStatsTable', \@etherhcindices, \@ethertablehc_columns)) {
             foreach my $interface (@{$self->{interfaces}}) {
               if ($interface->{ifIndex} == $etherstat->{flat_indices}) {
                 foreach my $key (grep /^dot3/, keys %{$etherstat}) {
                   $interface->{$key} = $etherstat->{$key};
+                  push(@{$interface->{columns}}, $key);
                 }
-                push(@{$interface->{columns}}, @ethertablehc_columns);
                 if (grep /^dot3HCStatsFCSErrors/, @{$interface->{columns}}) {
                   @{$interface->{columns}} = grep {
                     $_ if $_ ne 'dot3StatsFCSErrors';
@@ -251,8 +284,8 @@ sub init {
               if ('1.3.6.1.2.1.2.2.1.1.'.$interface->{ifIndex} eq $etherstat->{etherStatsDataSource}) {
                 foreach my $key (grep /^etherStats/, keys %{$etherstat}) {
                   $interface->{$key} = $etherstat->{$key};
+                  push(@{$interface->{columns}}, $key);
                 }
-                push(@{$interface->{columns}}, @rmontable_columns);
                 last;
               }
             }
@@ -280,11 +313,59 @@ sub init {
           $interface->init_etherstats;
         }
         if (scalar(@{$self->{interfaces}}) == 0) {
-          $self->add_unknown('device probably has no RMON-MIB or ETHERLIKE-MIB');
+          $self->add_unknown('device probably has no RMON-MIB or EtherLike-MIB');
         }
       }
     }
   }
+  if ($self->opts->report =~ /^(\w+)\+address/) {
+    $self->override_opt('report', $1);
+    # flat_indices, weil die Schluesselelemente ipAddressAddrType+ipAddressAddr
+    # not-accessible sind und im Index stecken.
+    if (scalar(@{$self->{interfaces}}) > 0) {
+      my $interfaces_by_index = {};
+      map {
+          $interfaces_by_index->{$_->{ifIndex}} = $_;
+      } @{$self->{interfaces}};
+      my $indexpattern = join('|', map {
+          $_->{ifIndex}
+      } @{$self->{interfaces}});
+      $self->override_opt('name', '^('.$indexpattern.')$');
+      $self->override_opt('drecksptkdb', '^('.$indexpattern.')$');
+      $self->override_opt('regexp', 1);
+
+      $self->get_snmp_objects('IP-MIB', qw(ipv4InterfaceTableLastChange ipv6InterfaceTableLastChange));
+      $self->{ipv4InterfaceTableLastChange} ||= 0;
+      $self->{ipv6InterfaceTableLastChange} ||= 0;
+      $self->{ipv46InterfaceTableLastChange} =
+          $self->{ipv4InterfaceTableLastChange} > $self->{ipv6InterfaceTableLastChange} ?
+          $self->{ipv4InterfaceTableLastChange} : $self->{ipv6InterfaceTableLastChange};
+      $self->{bootTime} = time - $self->uptime();
+      $self->{ipAddressTableLastChange} = $self->{bootTime} + $self->timeticks($self->{ipv46InterfaceTableLastChange} / 100);
+
+      $self->update_entry_cache(0, 'IP-MIB', 'ipAddressTable', 'ipAddressIfIndex', $self->{ipAddressTableLastChange});
+      my @address_indices = $self->get_cache_indices('IP-MIB', 'ipAddressTable', 'ipAddressIfIndex');
+      $self->{addresses} = [];
+      if (@address_indices) {
+        # es gibt adressen zu den ausgewaehlten interfaces
+        foreach ($self->get_snmp_table_objects_with_cache(
+            'IP-MIB', 'ipAddressTable', 'ipAddressIfIndex', ['ipAddressIfIndex'], 0)) {
+          my $address = Classes::IFMIB::Component::InterfaceSubsystem::Address->new(%{$_});
+          push(@{$self->{addresses}}, $address);
+          if (exists $interfaces_by_index->{$address->{ipAddressIfIndex}}) {
+            if (exists  $interfaces_by_index->{$address->{ipAddressIfIndex}}->{ifAddresses}) {
+              push(@{$interfaces_by_index->{$address->{ipAddressIfIndex}}->{ifAddresses}}, $address->{ipAddressAddr});
+            } else {
+              $interfaces_by_index->{$address->{ipAddressIfIndex}}->{ifAddresses} = [$address->{ipAddressAddr}];
+            }
+          }
+        }
+      }
+      foreach (@{$self->{interfaces}}) {
+        $_->{ifAddresses} = exists $_->{ifAddresses} ? join(", ", @{$_->{ifAddresses}}) : "";
+      }
+    }
+  }
 }
 
 sub check {
@@ -388,6 +469,7 @@ sub check {
 sub update_interface_cache {
   my ($self, $force) = @_;
   my $statefile = $self->create_interface_cache_file();
+  $self->bulk_is_baeh(10);
   $self->get_snmp_objects('IFMIB', qw(ifTableLastChange));
   # "The value of sysUpTime at the time of the last creation or
   # deletion of an entry in the ifTable. If the number of
@@ -439,6 +521,7 @@ sub update_interface_cache {
       $self->{interface_cache}->{$_->{flat_indices}}->{ifName} = unpack("Z*", $_->{ifName}) if exists $_->{ifName};
       $self->{interface_cache}->{$_->{flat_indices}}->{ifAlias} = unpack("Z*", $_->{ifAlias}) if exists $_->{ifAlias};
     }
+    $self->enrich_interface_cache();
     $self->save_interface_cache();
   }
   $self->load_interface_cache();
@@ -458,6 +541,13 @@ sub update_interface_cache {
   return $must_update;
 }
 
+sub enrich_interface_cache {
+  my ($self) = @_;
+  # a dummy method. it can be used in Classes::XY::Component::InterfaceSubsystem
+  # to add for example vendor-specific port names to the interface cache
+  # which has been collected by get_snmp_tables(vendor-mib, tablexy, xyPortName
+}
+
 sub save_interface_cache {
   my ($self) = @_;
   $self->create_statefilesdir();
@@ -483,7 +573,7 @@ sub load_interface_cache {
       require $statefile;
     };
     if($@) {
-      printf "rumms\n";
+      printf "FATAL: Could not load cache!\n";
     }
     $self->debug(sprintf "load %s", Data::Dumper::Dumper($VAR1));
     $self->{interface_cache} = $VAR1;
@@ -551,6 +641,12 @@ sub get_interface_indices {
   return @indices;
 }
 
+sub enrich_interface_attributes {
+  my ($self, $interface) = @_;
+  # can be used by vendor-specific InterfaceSubsystem to add extra
+  # attributes
+}
+
 
 package Classes::IFMIB::Component::InterfaceSubsystem::Interface;
 our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
@@ -572,28 +668,34 @@ sub finish {
       $self->{ifDescr} = $1;
     }
   }
-  # Manche Stinkstiefel haben ifName, ifHighSpeed und z.b. ifInMulticastPkts,
-  # aber keine ifHC*Octets. Gesehen bei Cisco Switch Interface Nul0 o.ae.
-  if ($self->{ifName} && defined $self->{ifHCInOctets} && 
-      defined $self->{ifHCOutOctets} && $self->{ifHCInOctets} ne "noSuchObject") {
-    $self->{ifAlias} ||= $self->{ifName};
-    $self->{ifName} = unpack("Z*", $self->{ifName});
-    $self->{ifAlias} = unpack("Z*", $self->{ifAlias});
-    $self->{ifAlias} =~ s/\|/!/g if $self->{ifAlias};
-    bless $self, 'Classes::IFMIB::Component::InterfaceSubsystem::Interface::64bit';
-  }
-  if ((! exists $self->{ifInOctets} && ! exists $self->{ifOutOctets} &&
-      $self->mode =~ /device::interfaces::(usage|complete)/) ||
-      (! exists $self->{ifInErrors} && ! exists $self->{ifOutErrors} &&
-      $self->mode =~ /device::interfaces::(errors|complete)/) ||
-      (! exists $self->{ifInDiscards} && ! exists $self->{ifOutDiscards} &&
-      $self->mode =~ /device::interfaces::(discards|complete)/) ||
-      (! exists $self->{ifInUcastPkts} && ! exists $self->{ifOutUcastPkts} &&
-      $self->mode =~ /device::interfaces::(broadcast|complete)/)) {
-    bless $self, 'Classes::IFMIB::Component::InterfaceSubsystem::Interface::StackSub';
-  }
-  if ($self->{ifPhysAddress}) {
-    $self->{ifPhysAddress} = join(':', unpack('(H2)*', $self->{ifPhysAddress})); 
+  if ($self->mode =~ /device::interfaces::duplex/) {
+  } elsif ($self->mode =~ /device::interfaces::uptime/) {
+    $self->{sysUptime} = $self->get_snmp_object('MIB-2-MIB', 'sysUpTime', 0) / 100;
+    $self->{sysUptime64} = $self->uptime();
+  } else {
+    # Manche Stinkstiefel haben ifName, ifHighSpeed und z.b. ifInMulticastPkts,
+    # aber keine ifHC*Octets. Gesehen bei Cisco Switch Interface Nul0 o.ae.
+    if ($self->{ifName} && defined $self->{ifHCInOctets} && 
+        defined $self->{ifHCOutOctets} && $self->{ifHCInOctets} ne "noSuchObject") {
+      $self->{ifAlias} ||= $self->{ifName};
+      $self->{ifName} = unpack("Z*", $self->{ifName});
+      $self->{ifAlias} = unpack("Z*", $self->{ifAlias});
+      $self->{ifAlias} =~ s/\|/!/g if $self->{ifAlias};
+      bless $self, 'Classes::IFMIB::Component::InterfaceSubsystem::Interface::64bit';
+    }
+    if ((! exists $self->{ifInOctets} && ! exists $self->{ifOutOctets} &&
+        $self->mode =~ /device::interfaces::(usage|complete)/) ||
+        (! exists $self->{ifInErrors} && ! exists $self->{ifOutErrors} &&
+        $self->mode =~ /device::interfaces::(errors|complete)/) ||
+        (! exists $self->{ifInDiscards} && ! exists $self->{ifOutDiscards} &&
+        $self->mode =~ /device::interfaces::(discards|complete)/) ||
+        (! exists $self->{ifInUcastPkts} && ! exists $self->{ifOutUcastPkts} &&
+        $self->mode =~ /device::interfaces::(broadcast|complete)/)) {
+      bless $self, 'Classes::IFMIB::Component::InterfaceSubsystem::Interface::StackSub';
+    }
+    if ($self->{ifPhysAddress}) {
+      $self->{ifPhysAddress} = join(':', unpack('(H2)*', $self->{ifPhysAddress})); 
+    }
   }
   $self->init();
 }
@@ -718,6 +820,32 @@ sub init {
       $self->{ifSpeedText} = sprintf "%.2fB", $speed;
     }
     $self->{ifSpeedText} =~ s/\.00//g;
+  } elsif ($self->mode =~ /device::interfaces::uptime/) {
+    $self->{ifLastChangeRaw} = $self->{ifLastChange};
+    $self->{ifLastChange} = time -
+        $self->ago_sysuptime($self->{ifLastChange});
+    # Alter Text:
+    # Wenn sysUptime ueberlaeuft, dann wird's schwammig. Denn dann kann
+    # ich nicht sagen, ob ein ifLastChange ganz am Anfang passiert ist,
+    # unmittelbar nach dem Booten, oder grad eben vor drei Minuten, als
+    # der Ueberlauf stattfand. Ergo ist dieser Mode nach einer Uptime von
+    # 497 Tagen nicht mehr brauchbar.
+    # Und tatsaechlich gibt es Typen die lassen ihre Switche in den
+    # Filialen ueber ein Jahr durchlaufen und machen dann reihenweise Tickets auf.
+    # boot                   ifchange1  overflow  ifchange2
+    # |                      |          |         |
+    # |---------------------------------^---------------------------------^-----
+    #                                          |
+    #                                          check
+    # Zum Zeitpunkt des Checks ist ifchange1 groesser als die sysUptime
+    # Damit wird ifLastChange negativ.
+    # Eine Chance gibts dann noch, man geht davon aus, dass das der
+    # einzige Overflow war (tatsaechlich koennten ja mehrere passiert sein)
+    # Also: max(32bit) - ifchange1 + sysUptime
+    # ago_sysuptime fackelt das ganz gut ab.
+    $self->{ifLastChangeHuman} = scalar localtime $self->{ifLastChange};
+    $self->{ifDuration} = time - $self->{ifLastChange};
+    $self->{ifDurationMinutes} = $self->{ifDuration} / 60; # minutes
   }
   return $self;
 }
@@ -748,21 +876,37 @@ sub init_etherstats {
           100 * $self->{'delta_'.$stat} /
           ($self->{delta_InPkts} + $self->{delta_OutPkts}) : 0;
     }
+  } elsif ($self->mode =~ /device::interfaces::duplex/) {
+    if (defined $self->{dot3StatsDuplexStatus}) {
+    } elsif (! defined $self->{dot3StatsDuplexStatus} && $self->{ifType} !~ /ether/i) {
+        $self->{dot3StatsDuplexStatus} = "notApplicable";
+    } elsif (! defined $self->{dot3StatsDuplexStatus} && $self->implements_mib('EtherLike-MIB')) {
+      if (defined $self->opts->mitigation() &&
+          $self->opts->mitigation() eq 'ok') {
+        $self->{dot3StatsDuplexStatus} = "fullDuplex";
+      } else {
+        $self->{dot3StatsDuplexStatus} = "unknown";
+      }
+    } else {
+      $self->{dot3StatsDuplexStatus} = "unknown";
+    }
   }
   return $self;
 }
 
 sub check {
   my ($self) = @_;
-  my $full_descr = sprintf "%s%s",
+  my $full_descr = sprintf "%s%s%s",
       $self->{ifDescr},
       $self->{ifAlias} && $self->{ifAlias} ne $self->{ifDescr} ?
-          " (alias ".$self->{ifAlias}.")" : "";
+          " (alias ".$self->{ifAlias}.")" : "",
+      $self->{ifAddresses} ? " (addresses ".$self->{ifAddresses}.")" : "";
   if ($self->mode =~ /device::interfaces::complete/) {
     # uglatto, but $self->mode is an lvalue
     $Monitoring::GLPlugin::mode = "device::interfaces::operstatus";
     $self->check();
     if ($self->{ifOperStatus} eq "up") {
+          # kostenpflichtiges feature # device::interfaces::duplex
       foreach my $mode (qw(device::interfaces::usage
           device::interfaces::errors device::interfaces::discards
           device::interfaces::broadcast)) {
@@ -1003,6 +1147,37 @@ sub check {
           uom => '%',
       );
     }
+  } elsif ($self->mode =~ /device::interfaces::duplex/) {
+    $self->add_info(sprintf "%s duplex status is %s",
+        $self->{ifDescr}, $self->{dot3StatsDuplexStatus}
+    );
+    if ($self->{ifOperStatus} ne "up") {
+      $self->annotate_info(sprintf "oper %s", $self->{ifOperStatus});
+      $self->add_ok();
+    } elsif ($self->{dot3StatsDuplexStatus} eq "notApplicable") {
+      $self->add_ok();
+    } else {
+      if ($self->{dot3StatsDuplexStatus} eq "unknown") {
+        $self->add_unknown();
+      } elsif ($self->{dot3StatsDuplexStatus} eq "fullDuplex") {
+        $self->add_ok();
+      } else {
+        # kein critical, weil so irgendwie funktionierts ja
+        $self->add_warning();
+      }
+    }
+  } elsif ($self->mode =~ /device::interfaces::uptime/) {
+    $self->add_info(sprintf "%s was changed %s ago",
+        $full_descr, $self->human_timeticks($self->{ifDuration}));
+    $self->set_thresholds(metric => $self->{ifDescr}."_duration",
+        warning => "15:", critical => "5:");
+    $self->add_message($self->check_thresholds(
+        metric => $self->{ifDescr}."_duration",
+        value => $self->{ifDurationMinutes}));
+    $self->add_perfdata(
+        label => $self->{ifDescr}."_duration",
+        value => $self->{ifDurationMinutes},
+    );
   }
 }
 
@@ -1148,14 +1323,50 @@ sub init_etherstats {
 
 sub check {
   my ($self) = @_;
-  my $full_descr = sprintf "%s%s",
+  my $full_descr = sprintf "%s%s%s",
       $self->{ifDescr},
       $self->{ifAlias} && $self->{ifAlias} ne $self->{ifDescr} ?
-          " (alias ".$self->{ifAlias}.")" : "";
+          " (alias ".$self->{ifAlias}.")" : "",
+      $self->{ifAddresses} ? " (addresses ".$self->{ifAddresses}.")" : "";
   if ($self->mode =~ /device::interfaces::operstatus/) {
     $self->SUPER::check();
+  } elsif ($self->mode =~ /device::interfaces::duplex/) {
+    $self->SUPER::check();
   } else {
     $self->add_ok(sprintf '%s has no traffic', $full_descr);
   }
 }
 
+
+package Classes::IFMIB::Component::InterfaceSubsystem::Address;
+our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
+use strict;
+
+sub finish {
+  my ($self) = @_;
+  # INDEX { ipAddressAddrType, ipAddressAddr }
+  my @tmp_indices = @{$self->{indices}};
+  my $last_tmp = scalar(@tmp_indices) - 1;
+  # .1.3.6.1.2.1.4.24.7.1.7.1.4.0.0.0.0.32.2.0.0.1.4.10.208.143.81 = INTEGER: 25337
+  # IP-FORWARD-MIB::inetCidrRouteIfIndex.ipv4."0.0.0.0".32.2.0.0.ipv4."10.208.143.81" = INTEGER: 25337
+  # Frag mich jetzt keiner, warum dem ipv4 ein 1.4 entspricht. Ich kann
+  # jedenfalls der IP-FORWARD-MIB bzw. RFC4001 nicht entnehmen, dass fuer
+  # InetAddressType zwei Stellen des Index vorgesehen sind. Zumal nur die
+  # erste Stelle für die Textual Convention relevant ist. Aergert mich ziemlich,
+  # daß jeder bloede /usr/bin/snmpwalk das besser hinbekommt als ich.
+  # Was dazugelernt: 1=InetAddressType, 4=gehoert zur folgenden InetAddressIPv4
+  # und gibt die Laenge an. Noch mehr gelernt: wenn eine Table mit Integer und
+  # Octet String indiziert ist, dann ist die Groeße des Octet String Bestandteil
+  # der OID. Diese _kann_ weggelassen werden für den _letzten_ Index. Der ist
+  # halt dann so lang wie der Rest der OID.
+  # Mit einem IMPLIED-Keyword koennte die Laenge auch weggelassen werden.
+
+  $self->{ipAddressAddrType} = $self->mibs_and_oids_definition(
+      'INET-ADDRESS-MIB', 'InetAddressType', $tmp_indices[0]);
+  shift @tmp_indices;
+
+  $self->{ipAddressAddr} = $self->mibs_and_oids_definition(
+      'INET-ADDRESS-MIB', 'InetAddressMaker',
+      $self->{ipAddressAddrType}, @tmp_indices);
+}
+
