@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('JUNIPER-IVE-MIB', (qw(
       diskFullPercent)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking disks');
   $self->add_info(sprintf 'disk is %.2f%% full',
       $self->{diskFullPercent});
