@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('JUNIPER-IVE-MIB', (qw(
       iveMemoryUtil iveSwapUtil)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking memory');
   $self->add_info(sprintf 'memory usage is %.2f%%, swap usage is %.2f%%',
       $self->{iveMemoryUtil}, $self->{iveSwapUtil});
