@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_tables('NETSCREEN-NSRP-MIB', [
     ['members', 'nsrpVsdMemberTable', 'Classes::Juniper::NetScreen::Component::VsdSubsystem::Member'],
     ['clusters', 'nsrpClusterTable', 'Classes::Juniper::NetScreen::Component::VsdSubsystem::Cluster'],
@@ -16,7 +16,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   my $label = $self->{nsrpVsdMemberGroupId}.'_'.$self->{nsrpVsdMemberUnitId};
   $self->add_info(sprintf 'vsd member %s has status %s',
       $label, $self->{nsrpVsdMemberStatus});
