@@ -3,13 +3,13 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('LCOS-MIB', (qw(
       lcsStatusHardwareInfoTemperatureDegrees)));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking temperature');
   $self->add_info(sprintf 'temperature is is %.2f',
       $self->{lcsStatusHardwareInfoTemperatureDegrees});
