@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('LCOS-MIB', (qw(
       lcsStatusHardwareInfoTotalMemoryKbytes
       lcsStatusHardwareInfoFreeMemoryKbytes
@@ -15,7 +15,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking memory');
   $self->add_info(sprintf 'memory usage is %.2f%%',
       $self->{usage});
