@@ -3,7 +3,7 @@ our @ISA = qw(Classes::Lantronix);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   if ($self->mode =~ /device::hardware::health/) {
     $self->analyze_and_check_environmental_subsystem("Classes::Lantronix::SLS::Component::EnvironmentalSubsystem");
   } else {
@@ -17,12 +17,12 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('LARA-MIB', qw(checkHostPower));
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf 'host power status is %s', $self->{checkHostPower});
   if ($self->{checkHostPower} eq 'hasPower') {
     $self->add_ok();
