@@ -3,7 +3,7 @@ our @ISA = qw(Classes::Device);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   if ($self->implements_mib('S5-CHASSIS-MIB')) {
     bless $self, 'Classes::Nortel::S5';
     $self->debug('using Classes::Nortel::S5');
