@@ -3,7 +3,7 @@ our @ISA = qw(Classes::Device);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   if ($self->mode =~ /device::hardware::health/) {
     $self->analyze_and_check_environmental_subsystem("Classes::ENTITYSENSORMIB::Component::EnvironmentalSubsystem");
     $self->analyze_and_check_environmental_subsystem("Classes::HOSTRESOURCESMIB::Component::EnvironmentalSubsystem");
@@ -19,8 +19,18 @@ sub init {
     $self->analyze_and_check_mem_subsystem("Classes::HOSTRESOURCESMIB::Component::MemSubsystem");
   } elsif ($self->mode =~ /device::ha::/) {
     $self->analyze_and_check_ha_subsystem("Classes::PaloAlto::Component::HaSubsystem");
+  } elsif ($self->mode =~ /device::lb::session/) {
+    # it's not a load balancer, but session-usage is the best mode here
+    $self->analyze_and_check_session_subsystem("Classes::PaloAlto::Component::SessionSubsystem");
   } else {
     $self->no_such_mode();
   }
 }
 
+sub pretty_sysdesc {
+  my ($self, $sysDescr) = @_;
+  my $sw_version = $self->get_snmp_object('PAN-COMMON-MIB', 'panSysSwVersion');
+  my $hw_version = $self->get_snmp_object('PAN-COMMON-MIB', 'panSysHwVersion');
+  return sprintf "%s, sw version %s, hw version: %s",
+      $sysDescr, $sw_version, $hw_version;
+}
