@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   my $temp = 0;
   $self->get_snmp_tables('FOUNDRY-SN-AGENT-MIB', [
       ['temperatures', 'snAgentTempTable', 'Classes::RAPIDCITYMIB::Component::TemperatureSubsystem::Temperature'],
@@ -20,7 +20,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::TableItem);
 use strict;
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->{snAgentTempValue} /= 2;
   $self->add_info(sprintf 'temperature %s is %.2fC', 
       $self->{snAgentTempSlotNum}, $self->{snAgentTempValue});
