@@ -3,7 +3,7 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('STEELHEAD-MIB', qw(
     serviceStatus serialNumber systemVersion model
     serviceStatus systemHealth optServiceStatus systemTemperature
@@ -12,7 +12,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info(sprintf 'health state is %s', $self->{systemHealth});
   if ($self->{systemHealth} eq 'healthy') {
       $self->add_ok();
