@@ -1,17 +1,9 @@
 package Classes::SGOS::Component::EnvironmentalSubsystem;
-our @ISA = qw(Classes::SGOS);
+our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
-sub new {
-  my $class = shift;
-  my $self = {};
-  bless $self, $class;
-  $self->init();
-  return $self;
-}
-
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem} =
       Classes::SGOS::Component::SensorSubsystem->new();
   $self->{disk_subsystem} =
@@ -19,7 +11,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem}->check();
   $self->{disk_subsystem}->check();
   if (! $self->check_messages()) {
@@ -28,7 +20,7 @@ sub check {
 }
 
 sub dump {
-  my $self = shift;
+  my ($self) = @_;
   $self->{sensor_subsystem}->dump();
   $self->{disk_subsystem}->dump();
 }
