@@ -3,7 +3,7 @@ our @ISA = qw(Classes::Device);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   if ($self->mode =~ /device::hardware::health/) {
     $self->analyze_and_check_environmental_subsystem("Classes::Server::Linux::Component::EnvironmentalSubsystem")
   } elsif ($self->mode =~ /device::hardware::load/) {
@@ -14,7 +14,7 @@ sub init {
     $self->analyze_and_check_mem_subsystem("Classes::Server::Linux::Component::MemSubsystem");
   } elsif ($self->mode =~ /device::process::status/) {
     $self->analyze_and_check_process_subsystem("Classes::UCDMIB::Component::ProcessSubsystem");
-  } elsif ($self->mode =~ /device::uptime/) {
+  } elsif ($self->mode =~ /device::uptime/ && $self->implements_mib("HOST-RESOURCES-MIB")) {
     $self->analyze_and_check_uptime_subsystem("Classes::HOSTRESOURCESMIB::Component::UptimeSubsystem");
   } else {
     $self->no_such_mode();
