@@ -3,7 +3,7 @@ our @ISA = qw(Classes::Server::Linux);
 use strict;
 
 sub new {
-  my $class = shift;
+  my ($class) = @_;
   my $self = {};
   bless $self, $class;
   $self->init();
@@ -11,7 +11,7 @@ sub new {
 }
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->{mem_subsystem} =
       Classes::UCDMIB::Component::MemSubsystem->new();
   $self->{swap_subsystem} =
@@ -19,13 +19,13 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->{mem_subsystem}->check();
   $self->{swap_subsystem}->check();
 }
 
 sub dump {
-  my $self = shift;
+  my ($self) = @_;
   $self->{mem_subsystem}->dump();
   $self->{swap_subsystem}->dump();
 }
