@@ -3,15 +3,15 @@ our @ISA = qw(Monitoring::GLPlugin::SNMP::Item);
 use strict;
 
 sub init {
-  my $self = shift;
+  my ($self) = @_;
   $self->get_snmp_objects('UCD-SNMP-MIB', (qw(
-      memTotalSwap memAvailSwap memTotalReal memAvailReal memBuffer memCached
-      memMinimumSwap memSwapError memSwapErrorMsg)));
+      memTotalSwap memTotalReal memTotalFree memAvailReal
+      memBuffer memCached memShared)));
 
   # basically buffered memory can always be freed up (filesystem cache)
   # https://kc.mcafee.com/corporate/index?page=content&id=KB73175
   my $mem_available = $self->{memAvailReal};
-  foreach (qw(memBuffer memCached)) {
+  foreach (qw(memBuffer memCached memShared)) {
     $mem_available += $self->{$_} if defined($self->{$_});
   }
 
@@ -20,7 +20,7 @@ sub init {
 }
 
 sub check {
-  my $self = shift;
+  my ($self) = @_;
   $self->add_info('checking memory');
   if (defined $self->{mem_usage}) {
     $self->add_info(sprintf 'memory usage is %.2f%%',
